[![Build Status](https://travis-ci.org/thomassampson/intelex_sdk.svg?branch=master)](https://travis-ci.org/thomassampson/intelex_sdk) [![PyPI version](https://badge.fury.io/py/intelex.svg)](https://badge.fury.io/py/intelex)

# Intelex Python SDK

## Installation

```python
pip install intelex
```

## USAGE

```python
import intelex as ilx

# Get current SDK version
ilx.get_version()
```